import { BetaAnalyticsDataClient } from "@google-analytics/data";
import { createStorage } from "unstorage";
import memoryDriver from "unstorage/drivers/memory";
const storage = createStorage({
  driver: memoryDriver()
});
export const useGoogleAnalyticsViews = async (config, analyticsCache) => {
  let restTimer;
  const { credentialsFile, credentials, propertyId, exact } = config.pageViews;
  let opts = {};
  if (credentials) {
    opts["credentials"] = credentials;
  } else if (credentialsFile) {
    opts["keyFilename"] = credentialsFile;
  } else {
    throw new Error("Unable to locate Google Analytics credentials");
  }
  const analyticsDataClient = new BetaAnalyticsDataClient(opts);
  await storage.setItem("cache:analyticsCacheRefresh", false);
  await storage.setItem("cache:analyticsCacheProcessing", true);
  const [response] = await analyticsDataClient.runReport({
    property: `properties/${propertyId}`,
    dimensions: [{ "name": "pagePath" }],
    "dateRanges": [{ "startDate": "2018-12-31", "endDate": "2099-01-01" }],
    metrics: [{ "name": "screenPageViews" }],
    dimensionFilter: {
      "filter": {
        fieldName: "pagePath",
        stringFilter: {
          matchType: "BEGINS_WITH",
          value: "/"
        }
      }
    }
  });
  const results = {};
  if (response.rows) {
    for (const row of response.rows) {
      if (row && row.dimensionValues && row.dimensionValues.length > 0 && row.metricValues) {
        let key = row.dimensionValues[0].value;
        if (!exact && key != "/") {
          key = key.replace(/\/$/, "");
        }
        if (key in results) {
          results[key] += parseInt(row.metricValues[0].value);
        } else {
          results[key] = parseInt(row.metricValues[0].value);
        }
      }
    }
    await storage.setItem("cache:analytics", results);
    await storage.setItem("cache:analyticsCacheProcessing", false);
    analyticsCache = results;
    clearTimeout(restTimer);
    setTimeout(async () => {
      await storage.setItem("cache:analyticsCacheRefresh", true);
    }, 15 * 60 * 1e3);
  }
  return analyticsCache;
};
