import { appendHeader, defineEventHandler, getQuery } from "h3";
import { useGoogleAnalyticsViews } from "../../composables/useGoogleAnalyticsViews.mjs";
import { useRuntimeConfig } from "#imports";
import memoryDriver from "unstorage/drivers/memory";
import { createStorage } from "unstorage";
const storage = createStorage({
  driver: memoryDriver()
});
storage.setItemRaw("cache:analytics", null);
storage.setItemRaw("cache:analyticsCacheProcessing", false);
storage.setItemRaw("cache:analyticsCacheRefresh", false);
export default defineEventHandler(async (event) => {
  let analyticsCache = await storage.getItemRaw("cache:analytics");
  const analyticsCacheProcessing = await storage.getItemRaw("cache:analyticsCacheProcessing");
  const analyticsCacheRefresh = await storage.getItemRaw("cache:analyticsCacheRefresh");
  appendHeader(event, "Access-Control-Allow-Origin", "*");
  appendHeader(event, "Content-Type", "application/json");
  const query = getQuery(event);
  let path = query.path;
  const config = await useRuntimeConfig();
  if (!config.exact && path != "/") {
    path = path.replace(/\/$/, "");
  }
  const shouldRefresh = !analyticsCacheProcessing && (analyticsCache === null || analyticsCacheRefresh);
  if (shouldRefresh) {
    analyticsCache = await useGoogleAnalyticsViews(config, analyticsCache);
    await storage.setItemRaw("cache:analytics", analyticsCache);
  }
  if (analyticsCache != null) {
    if (path === "*") {
      return analyticsCache;
    } else if (path in analyticsCache) {
      return { views: parseInt(analyticsCache[path]) };
    }
  }
  return { views: 0, empty: true };
});
